==> ejc-probuilddiary-impl-3.0.0-20220916.091102-6-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonMaterialEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-材料进场情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_material")
public class PersonMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="material_num")
    private BigDecimal materialNum; // 材料验收次数
    @TableField(value="concrete_num")
    private BigDecimal concreteNum; // 混凝土验收次数
    @TableField(value="material_memo")
    private String materialMemo; // 工作描述
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(BigDecimal materialNum) {
        this.materialNum = materialNum;
    }
    public BigDecimal getConcreteNum() {
        return concreteNum;
    }

    public void setConcreteNum(BigDecimal concreteNum) {
        this.concreteNum = concreteNum;
    }
    public String getMaterialMemo() {
        return materialMemo;
    }

    public void setMaterialMemo(String materialMemo) {
        this.materialMemo = materialMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.071841-10-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonMaterialEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-材料进场情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_material")
public class PersonMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="material_num")
    private BigDecimal materialNum; // 材料验收次数
    @TableField(value="concrete_num")
    private BigDecimal concreteNum; // 混凝土验收次数
    @TableField(value="material_memo")
    private String materialMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(BigDecimal materialNum) {
        this.materialNum = materialNum;
    }
    public BigDecimal getConcreteNum() {
        return concreteNum;
    }

    public void setConcreteNum(BigDecimal concreteNum) {
        this.concreteNum = concreteNum;
    }
    public String getMaterialMemo() {
        return materialMemo;
    }

    public void setMaterialMemo(String materialMemo) {
        this.materialMemo = materialMemo;
    }
    
}
